@@ -4,7 +4,7 @@ use strict;
 use Class::ISA;
 use Scalar::Util;
 
-$CGI::Application::VERSION = '4.50_51';
+$CGI::Application::VERSION = '4.60_1';
 
 my %INSTALLED_CALLBACKS = (
 #	hook name          package                 sub
@@ -2523,19 +2523,14 @@ L<http://www.cgi-app.org>
 B<Support Mailing List>
 
 If you have any questions, comments, bug reports or feature suggestions,
-post them to the support mailing list!  To join the mailing list, simply
-send a blank message to "cgiapp-subscribe@lists.erlbaum.net".
-
-B<IRC>
-
-You can also drop by C<#cgiapp> on C<irc.perl.org> with a good chance of finding
-some people involved with the project there.
+post them to the support mailing list!  To join the mailing list, visit 
+http://lists.openlib.org/mailman/listinfo/cgiapp
 
 B<Source Code>
 
 This project is managed using git and is available on Github:
 
-    L<https://github.com/MartinMcGrath/CGI--Application>
+L<https://github.com/MartinMcGrath/CGI--Application>
 
 =head1 SEE ALSO
 
@@ -2597,8 +2592,8 @@ which are documented in the C<Changes> file.
 
 Thanks also to all the members of the CGI-App mailing list!
 Your ideas, suggestions, insights (and criticism!) have helped
-shape this module immeasurably.  (To join the mailing list, simply
-send a blank message to "cgiapp-subscribe@lists.erlbaum.net".)
+shape this module immeasurably.  (To join the mailing list, visit 
+http://lists.openlib.org/mailman/listinfo/cgiapp )
 
 =head1 LICENSE
 
